"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.projectContainsGeneratorsOrExecutors = exports.findProjectsWithGeneratorsOrExecutors = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const fs_1 = require("fs");
const path = require("node:path");
function default_1(host, options) {
    var _a;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const projects = yield findProjectsWithGeneratorsOrExecutors(host);
        const packageDetails = [];
        (_a = options.exclude) !== null && _a !== void 0 ? _a : (options.exclude = []);
        const excludedProjects = Array.isArray(options.exclude)
            ? options.exclude
            : options.exclude.split(',');
        for (const project of projects) {
            if (excludedProjects.includes(project.name)) {
                continue;
            }
            packageDetails.push(generateDocsForProject(options, project, host));
        }
        (0, devkit_1.generateFiles)(host, path.join(__dirname, 'templates/root'), options.outputDirectory, {
            packageDetails,
            includeFrontMatter: !options.skipFrontMatter,
        });
        if (!options.skipFormat) {
            yield (0, devkit_1.formatFiles)(host);
        }
    });
}
exports.default = default_1;
function generateDocsForProject(options, project, host) {
    var _a, _b;
    let gettingStartedFile = options.gettingStartedFile.replace('<src>', project.root);
    if (options.verboseLogging) {
        console.log('Loading getting started file:', gettingStartedFile);
    }
    gettingStartedFile = host.exists(gettingStartedFile)
        ? gettingStartedFile
        : null;
    if (!gettingStartedFile && options.verboseLogging) {
        console.log('Getting started file not found');
    }
    const generatorsCollection = project.generators
        ? (0, devkit_1.readJson)(host, `${project.root}/generators.json`)
        : {};
    const generators = Object.fromEntries(Object.entries((_a = generatorsCollection.generators) !== null && _a !== void 0 ? _a : {}).filter(([, config]) => !config.hidden));
    const executorsCollection = project.executors
        ? (0, devkit_1.readJson)(host, `${project.root}/executors.json`)
        : {};
    const executors = Object.fromEntries(Object.entries((_b = executorsCollection.executors) !== null && _b !== void 0 ? _b : {}).filter(([, config]) => !config.hidden));
    const packageName = (0, devkit_1.readJson)(host, `${project.root}/package.json`).name;
    const projectFileName = (0, devkit_1.names)(project.name).fileName;
    (0, devkit_1.generateFiles)(host, path.join(__dirname, 'templates/index'), options.outputDirectory, {
        projectFileName,
        packageName,
        project,
        generators,
        executors,
        underscore: '_',
        gettingStartedMd: gettingStartedFile
            ? (0, fs_1.readFileSync)(gettingStartedFile).toString()
            : '',
        frontMatter: options.skipFrontMatter
            ? null
            : {
                title: `${packageName}`,
                summary: `${packageName}`,
            },
    });
    for (const [generatorName, config] of Object.entries(generators)) {
        const generatorFileName = (0, devkit_1.names)(generatorName).fileName;
        const schema = (0, devkit_1.readJson)(host, path.relative(process.cwd(), path.resolve(project.root, config.schema)));
        (0, devkit_1.generateFiles)(host, path.join(__dirname, 'templates/detail'), `${options.outputDirectory}/${projectFileName}/generators`, {
            projectFileName,
            project,
            generatorName,
            generatorFileName,
            schema,
            packageName,
        });
    }
    Object.entries(executors).forEach(([generatorName, config]) => {
        const generatorFileName = (0, devkit_1.names)(generatorName).fileName;
        const schema = (0, devkit_1.readJson)(host, path.relative(process.cwd(), path.resolve(project.root, config.schema)));
        (0, devkit_1.generateFiles)(host, path.join(__dirname, 'templates/detail'), `${options.outputDirectory}/${projectFileName}/executors`, {
            projectFileName,
            project,
            generatorName,
            generatorFileName,
            schema,
            packageName,
        });
    });
    return {
        packageName,
        projectFileName,
        project,
        generators: Object.keys(generators).length,
        executors: Object.keys(executors).length,
    };
}
function findProjectsWithGeneratorsOrExecutors(host) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const projects = [];
        (0, devkit_1.getProjects)(host).forEach((configuration, project) => {
            const res = projectContainsGeneratorsOrExecutors(host, configuration);
            if (res) {
                projects.push(Object.assign(Object.assign(Object.assign({}, configuration), { name: project }), res));
            }
        });
        return projects;
    });
}
exports.findProjectsWithGeneratorsOrExecutors = findProjectsWithGeneratorsOrExecutors;
function projectContainsGeneratorsOrExecutors(host, project) {
    const executors = host.isFile(`${project.root}/executors.json`);
    const generators = host.isFile(`${project.root}/generators.json`);
    return !(executors || generators) ? false : { generators, executors };
}
exports.projectContainsGeneratorsOrExecutors = projectContainsGeneratorsOrExecutors;
//# sourceMappingURL=generator.js.map